@@ -15,7 +15,7 @@ from isc_common.bit import IsBitOn, TurnBitOn, TurnBitOff
 from isc_common.datetime import DateToStr
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.RPCResponse import RPCResponseConstant
-from isc_common.number import DelProps
+from isc_common.models.progresses import Progresses, ProgressesManager
 from isc_common.ws.webSocket import WebSocket
 from tracker.models.messages_state import Messages_state
 from tracker.models.messages_theme import Messages_theme
@@ -56,35 +56,37 @@ class LoginRequest(DSRequest):
                         if ip_address != ip:
                             self.response = dict(status=RPCResponseConstant.statusLoginIncorrect, errorMessage=f'Вход с логином "{login}" уже выполнен на {ip_address}')
                     else:
+
                         self.response = dict(
-                            status=RPCResponseConstant.statusSuccess,
-                            login=login,
-                            userId=user.id,
-                            chatInfo=LoginRequest.get_chats(user),
                             captionUser=user.get_short_name,
+                            chatInfo=LoginRequest.get_chats(user),
                             codeGroup="",
+                            dynDataSources=settings.DYNAMIC_CLASS.get_datasources(),
                             fio=user.get_short_name,
-                            user_short_name=user.get_short_name,
-                            user_full_name=user.get_full_name,
-                            user__color=user.color if user.color != None and user.color != 'undefined' else 'black',
+                            frequencyOfPollingUnreadMessages=settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES,
                             isAdmin=user.is_admin,
                             isDevelop=user.is_develop,
-                            message_state_new_id=Messages_state.message_state_new().id,
-                            message_state_new_name=Messages_state.message_state_new().name,
+                            jsLogDebug=settings.JS_LOG_DEBUG if settings.JS_LOG_DEBUG == 1 else 0,
+                            KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
+                            login=login,
                             message_state_delivered_id=Messages_state.message_state_delivered().id,
                             message_state_delivered_name=Messages_state.message_state_delivered().name,
-                            message_state_readed_id=Messages_state.message_state_readed().id,
-                            message_state_readed_name=Messages_state.message_state_readed().name,
+                            message_state_new_id=Messages_state.message_state_new().id,
+                            message_state_new_name=Messages_state.message_state_new().name,
                             message_state_not_readed_id=Messages_state.message_state_not_readed().id,
                             message_state_not_readed_name=Messages_state.message_state_not_readed().name,
-                            dynDataSources=settings.DYNAMIC_CLASS.get_datasources(),
+                            message_state_readed_id=Messages_state.message_state_readed().id,
+                            message_state_readed_name=Messages_state.message_state_readed().name,
+                            Operations_Plan=settings.OPERATIONS_PLAN.OPERSTYPES,
+                            # progresses=[ProgressesManager.getRecord(item) for item in Progresses.objects.filter(user=user)],
+                            status=RPCResponseConstant.statusSuccess,
+                            user__color=user.color if user.color != None and user.color != 'undefined' else 'black',
+                            user_full_name=user.get_full_name,
+                            user_short_name=user.get_short_name,
+                            userId=user.id,
                             ws_channel=ws_channel,
                             ws_host=settings.WS_HOST,
                             ws_port=settings.WS_PORT,
-                            jsLogDebug=settings.JS_LOG_DEBUG if settings.JS_LOG_DEBUG == 1 else 0,
-                            frequencyOfPollingUnreadMessages=settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES,
-                            KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
-                            Operations_Plan=settings.OPERATIONS_PLAN.OPERSTYPES,
                         )
                         request.session['ws_channel'] = ws_channel
                         request.session['ws_port'] = settings.WS_PORT
@@ -110,6 +112,7 @@ class LoginRequest(DSRequest):
         tetatet_chats_sender = []
         tetatet_chats = []
 
+        settings.LOCKS.acquire('LoginRequest.get_chats')
         for chat in Chat_user_user.objects.filter(user_reciver=user):
             tetatet_chats_reciver.append(dict(
                 id=chat.common_id,
@@ -172,6 +175,7 @@ class LoginRequest(DSRequest):
                             description='Группа создана автоматически'))[0].id
                 ],
             ) for chat_users in Chat_usersView.objects.filter(user=user)]
+        settings.LOCKS.release('LoginRequest.get_chats')
 
         return dict(
             group_chats=group_chats,
@@ -183,6 +187,7 @@ class LoginRequest(DSRequest):
         _user = user
         _bot = bot
 
+        settings.LOCKS.acquire('LoginRequest.send_bot_message')
         if not isinstance(_user, User) and isinstance(_user, int):
             _user = User.objects.get(id=_user)
 
@@ -246,3 +251,4 @@ class LoginRequest(DSRequest):
                 ChatsManager.refresh_chat_menu(user=_user, logger=logger)
                 time.sleep(3)
             send()
+        settings.LOCKS.release('LoginRequest.send_bot_message')
