@@ -1,3 +1,24 @@
+import re
+
+
+def uncapitalize(str):
+    return str[0:1].lower() + str[1:]
+
+
+def dbl_qutes_str(str):
+    return f'"{str}"'
+
+
+def qutes_str(str):
+    return f"'{str}'"
+
+
+def delete_dbl_spaces(value):
+    if value == None:
+        return value
+    return re.sub('\s+', ' ', value).strip();
+
+
 class Common:
     @staticmethod
     def get_size_file_str(value):
@@ -21,5 +42,3 @@ class Common:
     def arraund_error(error):
         str = '!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
         return f'\n{str}\n{error}\n{str}'
-
-
