@@ -1,16 +1,19 @@
 import logging
+import sys
+import traceback
 from contextlib import contextmanager
 
 from django.conf import settings
 from django.utils import timezone
-from isc_common.auth.models.user import User
+from tqdm import tqdm
+
 from isc_common.bit import IsBitOff
 from isc_common.models.progresses import Progresses
 from isc_common.ws.progressStack import ProgressStack
-from tqdm import tqdm
 
 logger = logging.getLogger(__name__)
 
+
 class ProgressDroped(Exception):
     ...
 
@@ -21,15 +24,22 @@ def managed_progress(qty, user, id, message='Обработано позиций
     try:
         yield progress
         progress.close()
-    except Exception as ex:
+    except ProgressDroped as ex:
         progress.close()
         if callable(progress.except_func):
             progress.except_func(progress)
         raise ex
-
-
-def clean_progresses():
-    Progresses.objects.all().delete()
+    except Exception as ex:
+        exc_info = sys.exc_info()
+        stackTrace = traceback.format_exception(*exc_info)
+        stackTrace = '<br>'.join(stackTrace)
+        stackTrace = f'<pre>{stackTrace}</pre>'
+        del exc_info
+        progress.sendError(message=str(ex), stackTrace=stackTrace)
+        if callable(progress.except_func):
+            progress.except_func(progress)
+        progress.close()
+        raise ex
 
 
 class Progress:
@@ -38,7 +48,9 @@ class Progress:
     except_func = None
     enable_ws_progress = None
 
-    def __init__(self, qty, user, id, message='Обработано позиций', title='Обработано позиций', props=0):
+    def __init__(self, user, id, qty=0, message='Обработано позиций', title='Обработано позиций', label_contents=None, props=0):
+        from isc_common.auth.models.user import User
+
         self.message = message
         self.title = title
         self.props = props
@@ -48,68 +60,59 @@ class Progress:
         if self.enable_ws_progress == True:
             if isinstance(user, int):
                 self.user = User.objects.get(id=user)
-            elif not isinstance(user, User):
-                raise Exception(f'user must be User instance.')
-            else:
+            elif isinstance(user, User):
                 self.user = user
+            else:
+                raise Exception(f'user must be User instance or User_id.')
+
         self.qty = qty
 
         if self.enable_ws_progress == False:
             self.pbar = tqdm(total=qty)
         else:
-            if self.qty > 0:
-                channel = f'common_{self.user.username}'
-                self.progress = ProgressStack(
-                    host=settings.WS_HOST,
-                    port=settings.WS_PORT,
-                    channel=channel,
+            # if self.qty > 0:
+            channel = f'common_{self.user.username}'
+            self.progress = ProgressStack(
+                host=settings.WS_HOST,
+                port=settings.WS_PORT,
+                channel=channel,
+                props=self.props,
+                user_id=self.user.id
+            )
+
+            self.demand_str = f'<h3>{self.message}</h3>'
+
+            # if not self.check_exists():
+            self.progress.show(
+                cntAll=qty,
+                id=self.id,
+                label_contents=label_contents if label_contents else self.demand_str,
+                title=f'<b>{title}</b>',
+            )
+
+            # if IsBitOff(props, 1):
+            self.progresses, created = Progresses.objects.get_or_create(
+                id_progress=self.id,
+                user=self.user,
+                defaults=dict(
+                    cnt=0,
+                    label_contents=self.demand_str,
+                    qty=self.qty,
+                    message=self.message,
                     props=self.props,
-                    user_id=self.user.id
+                    title=self.title,
+                    lastmodified=timezone.now()
                 )
-
-                self.demand_str = f'<h3>{self.message}</h3>'
-
-                if not self.check_exists():
-                    self.progress.show(
-                        cntAll=qty,
-                        id=self.id,
-                        label_contents=self.demand_str,
-                        title=f'<b>{title}</b>',
-                    )
-
-                    if IsBitOff(props, 1):
-                        self.progresses, created = Progresses.objects.get_or_create(
-                            id_progress=self.id,
-                            user=self.user,
-                            defaults=dict(
-                                cnt=0,
-                                label_contents=self.demand_str,
-                                qty=self.qty,
-                                message=self.message,
-                                props=self.props,
-                                title=self.title,
-                                lastmodified=timezone.now()
-                            )
-                        )
+            )
 
         self.cnt = 0
 
-    def check_4_exit(self):
-        from isc_common.models.deleted_progresses import Deleted_progresses
-        res = 0
-        for delted_process in Deleted_progresses.objects.filter(id_progress=self.id, user=self.user):
-            res += 1
-            delted_process.delete()
-
-        return res
-
     def check_exists(self):
-        res = Progresses.objects.filter(
-            id_progress=self.id,
-            user=self.user
-        ).count() > 0
+        return Progresses.objects.filter(id_progress=self.id, user=self.user).count() > 0
 
     def step(self):
+        from isc_common.models.deleted_progresses import Deleted_progresses
+
         res = 0
         if self.enable_ws_progress == True:
             if self.progress != None:
@@ -120,7 +123,8 @@ class Progress:
                 self.progresses.cnt = self.cnt
                 self.progresses.lastmodified = timezone.now()
                 self.progresses.save()
-                res = self.check_4_exit()
+                deleted_count = Deleted_progresses.objects.filter(id_progress=self.id, user=self.user).count()
+                return deleted_count
         else:
             self.pbar.update()
             logger.debug(str(self.pbar))
@@ -129,7 +133,13 @@ class Progress:
     def setContentsLabel(self, content):
         if self.progress != None:
             self.progress.setContentsLabel(labelContents=content, id=self.id)
-            self.progresses.labelContents = content
+            self.progresses.label_contents = content
+            self.progresses.save()
+
+    def setQty(self, qty):
+        if self.progress != None:
+            self.progress.setCntAll(cntAll=qty, id=self.id)
+            self.progresses.qty = qty
             self.progresses.save()
 
     def sendInfo(self, message):
@@ -140,6 +150,10 @@ class Progress:
         if self.progress != None:
             self.progress.sendWarn(message=message)
 
+    def sendError(self, message, stackTrace=None):
+        if self.progress != None:
+            self.progress.sendError(message=message, stackTrace=stackTrace)
+
     def sendMessage(self, type, message=None):
         if self.progress != None:
             self.progress.sendMessage(type=type, message=message)
