@@ -4,6 +4,7 @@ import sys
 import traceback
 
 import websocket
+from django.conf import settings
 
 
 class WebSocket:
@@ -12,7 +13,6 @@ class WebSocket:
 
     @staticmethod
     def recv(**kwrags):
-
         host = kwrags.get('host')
         logger = kwrags.get('logger')
 
@@ -31,16 +31,19 @@ class WebSocket:
             raise Exception(f'channel is not exists.')
 
         message = kwrags.get('message')
+
         if not message:
             raise Exception(f'message is not exists.')
 
         if not isinstance(message, dict):
             raise Exception(f'message is not dict instance')
 
+        settings.LOCKS.acquire('WebSocket.recv')
         try:
             url = f'ws://{host}:{port}/ws/{channel}/'
             ws = websocket.create_connection(url)
             ws.send(json.dumps(message))
+            settings.LOCKS.release('WebSocket.recv')
             return ws, json.loads(ws.recv())
         except Exception as ex:
 
@@ -54,11 +57,11 @@ class WebSocket:
                 logger.error(x)
 
             del exc_info
+            settings.LOCKS.release('WebSocket.recv')
             return None
 
     @staticmethod
     def send_message(**kwrags):
-
         host = kwrags.get('host')
         logger = kwrags.get('logger')
 
@@ -84,10 +87,12 @@ class WebSocket:
             raise Exception(f'message is not dict instance')
 
         try:
+            settings.LOCKS.acquire('WebSocket.send_message')
             url = f'ws://{host}:{port}/ws/{channel}/'
             ws = websocket.create_connection(url)
             ws.send(json.dumps(message))
             ws.close()
+            settings.LOCKS.release('WebSocket.send_message')
         except Exception as ex:
 
             exc_info = sys.exc_info()
@@ -100,6 +105,7 @@ class WebSocket:
                 logger.error(x)
 
             del exc_info
+            settings.LOCKS.release('WebSocket.send_message')
 
     def on_message(self, message):
         for proc in self.procedures:
